@@ -1,4 +1,5 @@
 #include "obgtkCombo.h"
+#include "obgtkItem.h"
 
 @implementation Gtk_Combo
 
@@ -38,10 +39,10 @@
   return self;
 }
 
-- set_item_string:(Gtk_Item *) item
+- set_item_string:(id) item
 	itemValue:(const gchar *) item_value
 {
-  gtk_combo_set_item_string(gtkcombo, item->gtkitem, item_value);
+  gtk_combo_set_item_string(gtkcombo, GTK_ITEM([item getGtkObject]), item_value);
   return self;
 }
 
@@ -50,5 +51,4 @@
   gtk_combo_set_popdown_strings(gtkcombo, strings);
   return self;
 }
-
 @end
