@@ -11,11 +11,9 @@
 }
 
 - castGtkContainer:(GtkContainer *) castitem;
-- border_width:(gint) width;
+- set_border_width:(gint) width;
 - add:(id) widget;
 - remove:(id) widget;
-- disable_resize;
-- enable_resize;
 - block_resize;
 - unblock_resize;
 - (gint)need_resize;
