@@ -1,15 +1,17 @@
-#include "obgtk.h"
+#include "obgtkContainer.h"
 
 @implementation Gtk_Container
+
 - castGtkContainer:(GtkContainer *) castitem
 {
+  self = [super castGtkWidget:GTK_WIDGET(castitem)];
   gtkcontainer = castitem;
-  return [super castGtkWidget:(GtkWidget *) castitem];
+  return self;
 }
 
-- border_width:(gint) width
+- set_border_width:(gint) width
 {
-  gtk_container_border_width(gtkcontainer, width);
+  gtk_container_set_border_width(gtkcontainer, width);
   return self;
 }
 
@@ -25,18 +27,6 @@
   return self;
 }
 
-- disable_resize
-{
-  gtk_container_disable_resize(gtkcontainer);
-  return self;
-}
-
-- enable_resize
-{
-  gtk_container_enable_resize(gtkcontainer);
-  return self;
-}
-
 - block_resize
 {
   gtk_container_block_resize(gtkcontainer);
@@ -49,10 +39,9 @@
   return self;
 }
 
-- need_resize
+- (gint)need_resize
 {
-  gtk_container_need_resize(gtkcontainer);
-  return self;
+  return gtk_container_need_resize(gtkcontainer);
 }
 
 - foreach:
@@ -63,6 +52,12 @@ callbackData:(gpointer) callback_data
   return self;
 }
 
+- foreach_method:(SEL) method
+{
+  gtk_container_foreach(gtkcontainer, (GtkCallback)obgtk_callback_relay, (gpointer)method);
+  return self;
+}
+
 - focus:(GtkDirectionType) direction
 {
   gtk_container_focus(gtkcontainer, direction);
@@ -73,4 +68,16 @@ callbackData:(gpointer) callback_data
 {
   return gtk_container_children(gtkcontainer);
 }
+
+- register_toplevel
+{
+  gtk_container_register_toplevel(gtkcontainer);
+  return self;
+}
+
+- unregister_toplevel
+{
+  gtk_container_unregister_toplevel(gtkcontainer);
+  return self;
+}
 @end
