@@ -17,19 +17,19 @@
   return [self castGtkEntry:GTK_ENTRY(gtk_entry_new())];
 }
 
-- set_text:(gchar *) text
+- set_text:(const gchar *) text
 {
   gtk_entry_set_text(gtkentry, text);
   return self;
 }
 
-- append_text:(gchar *) text
+- append_text:(const gchar *) text
 {
   gtk_entry_append_text(gtkentry, text);
   return self;
 }
 
-- prepend_text:(gchar *) text
+- prepend_text:(const gchar *) text
 {
   gtk_entry_prepend_text(gtkentry, text);
   return self;
@@ -69,4 +69,5 @@
   gtk_entry_set_max_length(gtkentry, max);
   return self;
 }
+
 @end
