@@ -15,7 +15,7 @@
 - set_text_alignment:(gfloat) x_align :(gfloat) y_align;
 - set_format_string:(gchar *) format;
 - set_adjustment:(id) adjustment;
-- reconfigure:(gfloat) value :(gfloat) min :(gfloat) max;
+- configure:(gfloat) value :(gfloat) min :(gfloat) max;
 - set_percentage:(gfloat) percentage;
 - set_value:(gfloat) value;
 - (gfloat) get_value;
