@@ -9,9 +9,10 @@
 @public
   GtkRadioMenuItem *gtkradiomenuitem;
 }
+- castGtkRadioMenuItem:(GtkRadioMenuItem *) castitem;
 - initWithRadioGroup:(GSList *) group;
 - initWithRadioGroupLabel:(GSList *) group
-		   aLabel:(gchar *) label;
+		    label:(gchar *) label;
 - (GSList *) group;
 @end
 
