@@ -11,13 +11,15 @@
 @public
   GtkTreeItem *gtktreeitem;
 }
-- init;
 - initWithLabel:(gchar *) label;
-- set_subtree:(Gtk_Tree *) subtree;
+- set_subtree:(id) subtree;
 - select;
 - deselect;
 - expand;
 - collapse;
+
+- castGtkTreeItem:(GtkTreeItem *) castitem;
+- remove_subtree;
 @end
 
 #endif /* OBGTK_TREE_ITEM_H */
