@@ -1,4 +1,4 @@
-#include "obgtk.h"
+#include "obgtkVScale.h"
 
 @implementation Gtk_VScale
 - init
@@ -7,8 +7,8 @@
   return self;
 }
 
-- initWithGtkAdjustment:(Gtk_Adjustment *) adjustment
+- initWithGtkAdjustment:(id) adjustment
 {
-  return [super castGtkScale:GTK_SCALE(gtk_vscale_new(adjustment->gtkadjustment))];
+  return [super castGtkScale:GTK_SCALE(gtk_vscale_new(GTK_ADJUSTMENT([adjustment getGtkObject])))];
 }
 @end
